@@ -222,7 +222,7 @@ class CORE_EXPORT QgsExpressionContextUtils
      * For instance, current page name and number.
      * \param atlas source atlas. If NULLPTR, a set of default atlas variables will be added to the scope.
      */
-    static QgsExpressionContextScope *atlasScope( QgsLayoutAtlas *atlas ) SIP_FACTORY;
+    static QgsExpressionContextScope *atlasScope( const QgsLayoutAtlas *atlas ) SIP_FACTORY;
 
     /**
      * Creates a new scope which contains variables and functions relating to a QgsLayoutItem.
@@ -318,13 +318,16 @@ class CORE_EXPORT QgsExpressionContextUtils
     class GetLayerVisibility : public QgsScopedExpressionFunction
     {
       public:
-        GetLayerVisibility( const QList<QgsMapLayer *> &layers );
+        GetLayerVisibility( const QList<QgsMapLayer *> &layers, double scale = 0 );
         QVariant func( const QVariantList &values, const QgsExpressionContext *, QgsExpression *, const QgsExpressionNodeFunction * ) override;
         QgsScopedExpressionFunction *clone() const override;
 
       private:
+        GetLayerVisibility();
 
-        const QList< QPointer< QgsMapLayer > > mLayers;
+        QList< QPointer< QgsMapLayer > > mLayers;
+        QMap< QPointer< QgsMapLayer >, QPair< double, double > > mScaleBasedVisibilityDetails;
+        double mScale;
 
     };
 
@@ -349,7 +352,7 @@ class QgsExpressionContextScopePopper
      * end of \a context. \a scope will be automatically popped and deleted when this QgsExpressionContextScopePopper
      * is destroyed.
      *
-     * Ownership of \a scope is transferred to the popper, but it is gauranteed to exist of the lifetime
+     * Ownership of \a scope is transferred to the popper, but it is guaranteed to exist of the lifetime
      * of the popper.
      */
     QgsExpressionContextScopePopper( QgsExpressionContext &context, QgsExpressionContextScope *scope )
