@@ -141,11 +141,6 @@ class MetaSearchDialog(QDialog, BASE_CLASS):
         self.mActionAddGisFile.triggered.connect(self.add_gis_file)
         self.btnShowXml.clicked.connect(self.show_xml)
 
-        # settings
-        self.radioTitleAsk.clicked.connect(self.set_ows_save_title_ask)
-        self.radioTitleNoAsk.clicked.connect(self.set_ows_save_title_no_ask)
-        self.radioTempName.clicked.connect(self.set_ows_save_temp_name)
-
         self.manageGui()
 
     def manageGui(self):
@@ -166,16 +161,6 @@ class MetaSearchDialog(QDialog, BASE_CLASS):
 
         self.reset_buttons()
 
-        # get preferred connection save strategy from settings and set it
-        save_strategy = self.settings.value('/MetaSearch/ows_save_strategy',
-                                            'title_ask')
-        if save_strategy == 'temp_name':
-            self.radioTempName.setChecked(True)
-        elif save_strategy == 'title_no_ask':
-            self.radioTitleNoAsk.setChecked(True)
-        else:
-            self.radioTitleAsk.setChecked(True)
-
         # install proxy handler if specified in QGIS settings
         self.install_proxy()
 
@@ -748,15 +733,10 @@ class MetaSearchDialog(QDialog, BASE_CLASS):
 
         # check for duplicates
         if sname in keys:  # duplicate found
-            if self.radioTitleAsk.isChecked():  # ask to overwrite
-                msg = self.tr('Connection {0} exists. Overwrite?').format(sname)
-                res = QMessageBox.warning(self, self.tr('Saving server'), msg,
-                                          QMessageBox.Yes | QMessageBox.No)
-                if res != QMessageBox.Yes:  # assign new name with serial
-                    sname = serialize_string(sname)
-            elif self.radioTitleNoAsk.isChecked():  # don't ask to overwrite
-                pass
-            elif self.radioTempName.isChecked():  # use temp name
+            msg = self.tr('Connection {0} exists. Overwrite?').format(sname)
+            res = QMessageBox.warning(self, self.tr('Saving server'), msg,
+                                      QMessageBox.Yes | QMessageBox.No)
+            if res != QMessageBox.Yes:  # assign new name with serial
                 sname = serialize_string(sname)
 
         # no dups detected or overwrite is allowed
